<p align="center">
  <img width = "250" src="docs/VPLanetLogo.png?raw=true"/>
</p>

<h1 align="center">BigPlanet: Big Data with VPLanet</h1>

<p align="center">
  <a href="https://VirtualPlanetaryLaboratory.github.io/bigplanet/">
    <img src="https://img.shields.io/badge/read-the_docs-blue.svg?style=flat">
  </a>
  <a href="https://github.com/VirtualPlanetaryLaboratory/bigplanet/actions/workflows/docs.yml">
    <img src="https://github.com/VirtualPlanetaryLaboratory/bigplanet/actions/workflows/docs.yml/badge.svg">
  </a> 
  <a href="LICENSE"><img src="https://img.shields.io/badge/license-MIT-purple.svg"></a>
  <a href="https://VirtualPlanetaryLaboratory.github.io/vplanet/conduct.html">
    <img src="https://img.shields.io/badge/Code%20of-Conduct-7d93c7.svg">
  </a>
  <br>
  <img src="https://img.shields.io/badge/Unit%20Tests-10-darkblue.svg">
  <a href="https://github.com/VirtualPlanetaryLaboratory/bigplanet/actions/workflows/tests.yml">
    <img src="https://github.com/VirtualPlanetaryLaboratory/bigplanet/actions/workflows/tests.yml/badge.svg">
  </a>
  <img src="https://img.shields.io/badge/Python-3.6--3.9-orange.svg">
  <br>
  <a href="https://github.com/VirtualPlanetaryLaboratory/bigplanet/actions/workflows/pip-install.yml">
    <img src="https://github.com/VirtualPlanetaryLaboratory/bigplanet/actions/workflows/pip-install.yml/badge.svg">
  </a>
  <img src="https://img.shields.io/badge/Python-3.6--3.9-orange.svg">
  <img src = "https://img.shields.io/badge/Platforms-Linux_|%20macOS-darkgreen.svg?style=flat">
</p>

A suite of data analysis and extraction routines for [VPLanet](https://github.com/VirtualPlanetaryLaboratory/vplanet) and designed to be used with [VSPACE](https://github.com/VirtualPlanetaryLaboratory/vspace) and [MultiPlanet](https://github.com/VirtualPlanetaryLaboratory/multi-planet) scripts. It can also generate files for use with the free version of the [VR Ulysses data explorer](https://www.vrulysses.com/download-ulysses). [Read the docs](https://VirtualPlanetaryLaboratory.github.io/bigplanet/) to learn how to get the most out of your `VPLanet` parameter sweeps.
